// Copyright (C) 2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

package main

import (
	"fmt"
	"os"

	"gopkg.in/ini.v1"

	"apollo/internal/lunar"
	"apollo/internal/service"
)

type User struct {
	Username string
	Password string
}

var (
	dynCoventry *ini.File = nil
	adminUser   *User
	setupFlag   bool = true
)

func dynInit(port uint16, tls bool) {
	var opt = ini.LoadOptions{Loose: true, Insensitive: true}
	var err error
	var web = fmt.Sprintf("%d", port)
	var covpath = workingDir + "/dynamic.conf"

	dynCoventry, err = ini.LoadSources(opt, covpath)
	if err != nil {
		dynCoventry = &ini.File{}
	}
	section := dynCoventry.Section("server")
	lunar.SetConfig(section, "webserver", web)
	if tls {
		lunar.SetConfig(section, "urlschema", "https")
	} else {
		lunar.SetConfig(section, "urlschema", "http")
	}

	if !section.HasKey("webadmin") {
		section.NewKey("webadmin", "admin")
	}

	setupFlag = section.HasKey("webpass")
	adminUser = &User{
		Username: lunar.GetConfig(section, "webadmin", "admin"),
		Password: lunar.GetConfig(section, "webpass", "XXX"),
	}
	err = dynCoventry.SaveTo(covpath)
	os.Chmod(covpath, 0600)
	if err == nil {
		err = lunar.ReloadCoventry()
	}
	if err != nil {
		service.Error(err)
	}
}
