// Copyright (C) 2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

package main

import (
	"strconv"

	"github.com/gofiber/fiber/v2"

	"apollo/internal/lunar"
	"apollo/internal/service"
)

func addLine(ctx *fiber.Ctx) error {
	id, line := lunar.NewLine()
	if line == nil {
		return ctx.Status(fiber.StatusBadRequest).SendString("No lines available")
	}

	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("add-line", fiber.Map{
		"page": config,
		"Id":   id,
		"Line": line,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func editLine(ctx *fiber.Ctx) error {
	tag := ctx.Params("id")
	if tag == "new" {
		return addLine(ctx)
	}

	id, err := strconv.Atoi(tag)
	if err != nil {
		id = 0
	}

	line := lunar.GetLine(id)
	if line == nil {
		return ctx.Status(fiber.StatusNotFound).SendString("Line is invalid")
	}

	form := "edit-line"
	if !line.Editable {
		form = "show-line"
	}

	lock.RLock()
	defer lock.RUnlock()
	err = ctx.Render(form, fiber.Map{
		"page": config,
		"Id":   id,
		"Line": line,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func editSettings(ctx *fiber.Ctx) error {
	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("settings", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}
