// Copyright (C) 2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

package main

import (
	"crypto/sha256"
	"encoding/hex"
	"syscall"

	"github.com/gofiber/fiber/v2"

	"apollo/internal/lunar"
	"apollo/internal/service"
)

func postSetup(ctx *fiber.Ctx) error {
	// Make sure we do nothing if already setup
	if setupFlag {
		return ctx.Status(fiber.StatusBadRequest).SendString("Apollo is already configured")
	}

	admin := ctx.FormValue("admin")
	passwd := ctx.FormValue("pass")
	verify := ctx.FormValue("verify")

	// Server side verification repeats javascript tests for non-js browsers
	if admin == "" {
		return ctx.Status(fiber.StatusBadRequest).SendString("Please enter an admin username.")
	}

	if passwd == "" {
		return ctx.Status(fiber.StatusBadRequest).SendString("Please enter a password.")
	}

	if passwd != verify {
		return ctx.Status(fiber.StatusBadRequest).SendString("Password does not match verify.")
	}

	// Process form and goto main...
	lock.Lock()
	defer lock.Unlock()

	section := dynCoventry.Section("server")
	digest := sha256.New()
	digest.Write([]byte(passwd + ":" + admin))
	passwd = hex.EncodeToString(digest.Sum(nil))
	section.NewKey("webpass", passwd)
	lunar.SetConfig(section, "webadmin", admin)

	covpath := workingDir + "/dynamic.conf"
	err := dynCoventry.SaveTo(covpath)
	if err != nil {
		service.Error(err)
		return ctx.Status(fiber.StatusBadRequest).SendString("Cannot save setup")
	}

	adminUser = &User{
		Username: admin,
		Password: passwd,
	}

	setupFlag = true
	return ctx.Redirect("/lines", fiber.StatusSeeOther)
}

func themeSetup(ctx *fiber.Ctx) error {
	server := lunar.GetServer()
	theme := lunar.GetConfig(server, "theme", "dark")
	if theme == "light" {
		theme = "dark"
	} else {
		theme = "light"
	}

	lunar.UpdateCoventry("server", "theme", theme)
	lunar.SaveCoventry()
	syscall.Kill(syscall.Getpid(), syscall.SIGHUP)
	return ctx.Redirect("/lines", fiber.StatusSeeOther)
}
