// Copyright (C) 2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

package main

import (
	"sort"

	"github.com/gofiber/fiber/v2"

	"apollo/internal/lunar"
	"apollo/internal/service"
)

func viewPing(ctx *fiber.Ctx) error {
	// render master site ping page
	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("ping", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func viewMain(ctx *fiber.Ctx) error {
	// will probably have some info pulled from status
	// will have button for change password, to add line, add group, etc...
	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("main", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func viewLines(ctx *fiber.Ctx) error {
	type Item struct {
		Id   int
		Line *lunar.Line
	}

	lines := lunar.GetLines()
	items := make([]Item, 0, len(lines))
	for key, value := range lines {
		items = append(items, Item{key, value})
	}

	sort.Slice(items, func(i, j int) bool {
		return items[i].Id < items[j].Id
	})

	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("lines", fiber.Map{
		"page":  config,
		"items": items,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func viewGroups(ctx *fiber.Ctx) error {
	// will probably pass group config, have manipulation functions
	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("groups", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func viewContacts(ctx *fiber.Ctx) error {
	// will form list from config, have print option
	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("contacts", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}

func viewSetup(ctx *fiber.Ctx) error {
	if setupFlag {
		return ctx.Redirect("/lines", fiber.StatusTemporaryRedirect)
	}

	lock.RLock()
	defer lock.RUnlock()
	err := ctx.Render("setup", fiber.Map{
		"page": config,
	})
	if err != nil {
		service.Error(err)
	}
	return err
}
