// Copyright (C) 2023 David Sugar, Tycho Softworks
// This code is licensed under MIT license

package types

import (
	"encoding/json"
	"errors"
	"time"
)

// lib.Duration allows json marshalling
type Duration time.Duration

// marshall as duration string (xhymzs...)
func (d Duration) MarshalJSON() ([]byte, error) {
	return json.Marshal(time.Duration(d).Truncate(time.Second).String())
}

// Parse duration
func (d Duration) Parse(text string) (Duration, error) {
	tmp, err := time.ParseDuration(text)
	return Duration(tmp.Truncate(time.Second)), err
}

// Duration as string
func (d Duration) String() string {
	return time.Duration(d).Truncate(time.Second).String()
}

// unmarshall from float or string form
func (d *Duration) UnmarshalJSON(b []byte) error {
	var v interface{}
	if err := json.Unmarshal(b, &v); err != nil {
		return err
	}
	switch value := v.(type) {
	case float64:
		*d = Duration(time.Duration(value).Truncate(time.Second))
		return nil
	case string:
		tmp, err := time.ParseDuration(value)
		if err != nil {
			return err
		}
		*d = Duration(tmp.Truncate(time.Second))
		return nil
	default:
		return errors.New("invalid duration")
	}
}
